"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const getConfig_1 = require("./config/getConfig");
const init_1 = require("./command/init");
const run_1 = require("./command/run");
const showHelp_1 = require("./showHelp");
const logger_1 = require("./logger");
const Logger_1 = require("./logger/Logger");
const NpmLogReporter_1 = require("./logger/reporters/NpmLogReporter");
const LogLevel_1 = require("./logger/LogLevel");
const JsonReporter_1 = require("./logger/reporters/JsonReporter");
// Parse CLI args
const cwd = process.cwd();
try {
    const config = getConfig_1.getConfig(cwd);
    // Initialize logger
    const logLevel = config.verbose ? LogLevel_1.LogLevel.verbose : LogLevel_1.LogLevel.info;
    const reporters = [
        config.reporter === "json"
            ? new JsonReporter_1.JsonReporter({ logLevel })
            : new NpmLogReporter_1.NpmLogReporter({
                logLevel,
                grouped: config.grouped,
            }),
    ];
    Logger_1.Logger.reporters = reporters;
    logger_1.logger.info(`Lage task runner - let's make it`);
    if (config.command[0] === "init") {
        init_1.init(cwd);
    }
    else {
        run_1.run(cwd, config, reporters);
    }
}
catch (e) {
    console.error(e);
    showHelp_1.showHelp(e.message);
}
